@@ -307,7 +307,6 @@ private:
 #endif
 	static BayonneSysexec *libexec;
 
-	static void execute(unsigned slot, const char *cmd);
 	static void readline(char *buf, unsigned max);
 
 	void run(void);
@@ -316,6 +315,8 @@ private:
 	~BayonneSysexec();
 
 public:
+	static void setEngine(const char *engine);
+	static void setArgv0(const char *cp);
 	static bool create(BayonneSession *s);
 	static void allocate(const char *path, size_t bs = 0, int pri = 0, const char *modpath = NULL);
 	static void cleanup(void);
