@@ -40,6 +40,7 @@ typedef struct
 	char tsid[16];
 }	slot_t;
 
+static const char *argv0 = LIBEXEC_PROGRAM;
 static slot_t *slot;
 static int pid = 0;
 static int pri = 1;
@@ -135,6 +136,32 @@ BayonneSysexec::~BayonneSysexec()
 	terminate();
 }
 
+void BayonneSysexec::setEngine(const char *engine)
+{
+	char *n = newString(argv0, strlen(argv0) + 16);
+	char *ep = strrchr(n, '/');
+	if(!ep)
+		return;
+	snprintf(++ep, 16, "%s.bin", engine);
+	argv0 = n;
+}
+
+void BayonneSysexec::setArgv0(const char *cp)
+{
+	char *n = newString(cp);
+	char *ep;
+
+	ep = strstr(n, "/.libs/");
+	if(!ep)
+		ep = strrchr(n, '/');
+	if(ep)
+		++ep;
+	else
+		ep = n;
+	strcpy(ep, "libexec.bin");
+	argv0 = n;
+}
+
 void BayonneSysexec::run(void)
 {
 	BayonneTSession *s;
@@ -283,128 +310,6 @@ void BayonneSysexec::startup(void)
 	libexec->start();
 }
 
-void BayonneSysexec::execute(unsigned ts, const char *cmd)
-{
-	int pid, fd;
-	char path[256];
-	char fname[32];
-	char buf[256];
-	char *args[12];
-	unsigned count = 3;
-	bool jar = false;
-	bool java = false;
-	char *ext, *dp;
-	unsigned diff;
-	int argc;
-	int rts = -1;	
-
-	if(!strnicmp(cmd, "exec::", 6))
-		snprintf(path, sizeof(path), "%s/%s", syspath, cmd + 6);
-	else
-		snprintf(path, sizeof(path), "%s/%s", libpath, cmd);
-	snprintf(fname, sizeof(fname), "%s/.libexec-%d", path_tmp, ts);
-
-	ext = strrchr(path, '.');
-	dp = strrchr(path, '/');
-	if(!ext)
-		goto normal;
-
-	diff = dp - path;
-
-	if(ext && (!stricmp(ext, ".exe") || !stricmp(ext, ".il")))
-	{
-		args[0] = PNET_PROGRAM;
-		args[1] = newString(path);
-		args[2] = NULL;
-		argc = 2;
-		setString(path, sizeof(path), PNET_PROGRAM);
-		goto launch;
-	}
-
-        if(ext && !stricmp(ext, ".class"))
-        {
-		*ext = 0;
-		args[0] = JAVA_PROGRAM;
-		snprintf(buf, sizeof(buf), "-Dbayonne.home=%s",
-			Process::getEnv("SERVER_PREFIX"));
-		args[1] = newString(buf);
-		snprintf(buf, sizeof(buf), "-Dbayonne.ramfs=%s",
-			Process::getEnv("SERVER_TMPFS"));
-		args[2] = newString(buf);
-		snprintf(buf, sizeof(buf), "-Dbayonne.tmpfs=%s",
-			Process::getEnv("SERVER_TMP"));
-		args[3] = newString(buf);
-                snprintf(buf, sizeof(buf), "-Dbayonne.tsid=%s", slot[ts].tsid);
-                args[4] = newString(buf);
-                args[5] = newString(++dp);
-                args[6] = NULL;
-		argc = 6;
-		setString(path, sizeof(path), JAVA_PROGRAM);
-                goto launch;       
-        }  
-
-	if(ext && !stricmp(ext, ".jar"))
-	{
-		args[0] = JAVA_PROGRAM;
-                snprintf(buf, sizeof(buf), "-Dbayonne.home=%s",
-                        Process::getEnv("SERVER_PREFIX"));
-                args[1] = newString(buf);
-                snprintf(buf, sizeof(buf), "-Dbayonne.ramfs=%s", 
-                        Process::getEnv("SERVER_TMPFS"));       
-                args[2] = newString(buf);      
-                snprintf(buf, sizeof(buf), "-Dbayonne.tmpfs=%s",
-                        Process::getEnv("SERVER_TMP"));
-                args[3] = newString(buf);  
-		snprintf(buf, sizeof(buf), "-Dbayonne.tsid=%s", slot[ts].tsid);
-		args[4] = newString(buf);
-		args[5] = "-jar";
-		args[6] = newString(++dp);
-		args[7] = NULL;
-		argc = 7;
-		setString(path, sizeof(path), JAVA_PROGRAM);
-		goto launch;
-	}
-
-
-normal:
-	args[0] = path;
-	args[1] = NULL;
-	argc = 1;
-
-launch:
-	pid = fork();
-	if(pid)
-	{
-		slot[ts].pid = pid;
-
-		if(err)
-			fprintf(stderr, "libexec starting; timeslot=%d, pid=%d, cmd=%s\n",
-				ts, pid, cmd);
-		return;
-	}
-
-	Process::setPosixSignal(SIGCHLD, SIG_DFL);
-	dup2(iopair[0], 1);
-	remove(fname);
-	mkfifo(fname, 0660);
-	fd = open(fname, O_RDWR);
-	dup2(fd, 0);
-
-	while(count < 20)
-		::close(count++);
-
-	snprintf(buf, sizeof(buf), "%d", ts);
-	Process::setEnv("PORT_TIMESLOT", strdup(buf), true);
-	Process::setEnv("PORT_TSESSION", slot[ts].tsid, true);
-
-	snprintf(buf, sizeof(buf), "%s start %d %s\n",
-		slot[ts].tsid, getpid(), fname);
-	write(1, buf, strlen(buf));
-
-	execv(path, args);
-	::exit(rts);		
-}
-
 void BayonneSysexec::readline(char *buf, unsigned max)
 {
 	unsigned count = 0;
@@ -435,6 +340,8 @@ void BayonneSysexec::allocate(const char *libexec, size_t bs, int pri, const cha
 	long opt;
 	char path[512];
 	char cwd[512];
+	char *argv[8];
+	char tmp[16];
 
 	slots = ts_count;
 
@@ -493,8 +400,11 @@ void BayonneSysexec::allocate(const char *libexec, size_t bs, int pri, const cha
 		syspath = libpath;
 
 	Process::detach();
+	dup2(iopair[0], 0);
+	dup2(iopair[0], 1);
 	dup2(fd, 2);
 	::close(fd);
+	::close(iopair[0]);
 
 	nice(pri);
 
@@ -524,43 +434,24 @@ void BayonneSysexec::allocate(const char *libexec, size_t bs, int pri, const cha
 	if(err)
 		fprintf(stderr, "libexec starting; path=%s\n", libpath);
 
-	slot = new slot_t[slots];
+	// !exec
+	argv[0] = "libexec.bin";
+	snprintf(tmp, sizeof(tmp), "%d", slots);
+	argv[1] = newString(tmp);
+	snprintf(tmp, sizeof(tmp), "%d", LIBEXEC_BUFFER);
+	argv[2] = newString(tmp);
+	snprintf(tmp, sizeof(tmp), "%d", interval);
+	argv[3] = newString(tmp);
+	argv[4] = newString(libpath);
+	argv[5] = newString(syspath);
+	argv[6] = NULL;
 
-	Process::setPosixSignal(SIGCHLD, child);
-	Process::setPosixSignal(SIGALRM, timer);
 
-	memset(slot, 0, sizeof(slot_t) * slots);
-	alarm(interval);
-
-	for(;;)
-	{	
-		len = ::read(iopair[0], buf, sizeof(buf));
-		if(len < sizeof(buf))
-			continue;
-
-		if(!stricmp(buf, "down"))
-		{
-			if(err)
-				fprintf(stderr, "libexec exiting; server down\n");
-			else
-				slog.notice("libexec exiting...");
-			stop();
-			::exit(0);
-		}
-
-		if(!strnicmp(buf, "serv", 4))
-			server_pid = atoi(buf + 4);
-
-		p = strchr(buf, ' ');
-		if(!p)
-			continue;
-
-		*(p++) = 0;
-		ts = atoi(buf);
-		strcpy(slot[ts].tsid, buf);
-		slot[ts].pid = 0;
-		execute(ts, p);
-	}		
+	for(int i = 3; i < 100; ++i)
+		::close(i);
+	execv(argv0, argv);
+	slog.error("libexec failed; exiting...");
+	::exit(-1);
 }
 
 bool BayonneSysexec::create(BayonneSession *s)
