@@ -1180,6 +1180,54 @@ bool BayonneSession::stateWait(Event *event)
         return enterCommon(event);
 }
 
+bool BayonneSession::stateHold(Event *event)
+{
+	if(enterHold(event))
+		return true;
+
+	switch(event->id)
+	{
+	case ENTER_STATE:
+		error("hold-failed");
+		setRunning();
+		return true;
+	}
+	return enterCommon(event);
+}
+
+bool BayonneSession::stateRecall(Event *event)
+{
+        if(enterRecall(event))
+                return true;
+
+        switch(event->id)
+        {
+        case ENTER_STATE:
+                error("recall-failed");    
+                setRunning();
+                return true;
+        }
+        return enterCommon(event); 
+}
+
+bool BayonneSession::stateXfer(Event *event)
+{
+	if(enterXfer(event))
+		return true;
+
+	switch(event->id)
+	{
+	case ENTER_STATE:
+		error("transfer-failed");
+		setRunning();
+		return true;
+	case TIMER_EXPIRED:
+		setState(STATE_HANGUP);
+		return true;
+	}
+	return enterCommon(event);
+}
+
 bool BayonneSession::stateDial(Event *event)
 {
         if(enterDial(event))
@@ -2057,6 +2105,21 @@ bool BayonneSession::enterDial(Event *event)
         return false;
 }
 
+bool BayonneSession::enterXfer(Event *event)
+{
+	return false;
+}
+
+bool BayonneSession::enterHold(Event *event)
+{
+	return false;
+}
+
+bool BayonneSession::enterRecall(Event *event)
+{
+	return false;
+}
+
 bool BayonneSession::enterBusy(Event *event)
 {
         return false;
