@@ -234,6 +234,172 @@ exit:
 	leave();
 }
 
+void BayonneTSession::sysTone(const char *tsid, char *tok)
+{
+	Event event;
+	const char *loc, *tone, *cp;
+	char *p;
+	timeout_t timeout = TIMEOUT_INF;
+	Audio::Level level = 26000;
+	TelTone::tonekey_t *key;
+
+	memset(&event, 0, sizeof(event));
+	event.id = TONE_LIBEXEC;
+	event.libexec.tid = tsid;
+	tone = strtok_r(NULL, " \t\r\n", &tok);
+	if(!tone)
+		return;
+	p = strchr(tone, '/');	
+	if(p)
+	{
+		*(p++) = 0;
+		loc = tone;
+		tone = p;
+	}
+	else
+		loc = server->getLast("location");
+	cp = strtok_r(NULL, " \t\r\n", &tok);
+	if(cp)
+		timeout = atol(cp);
+	cp = strtok_r(NULL, " \t\r\n", &tok);
+	if(cp && atoi(cp) > 0)
+		level = atoi(cp);
+	if(!timeout)
+		timeout = TIMEOUT_INF;
+	else if(timeout < 100)
+		timeout *= 1000;
+	if(!stricmp(tone, "dialtone"))
+		tone = "dial";
+	else if(!stricmp(tone, "ringback"))
+		tone = "ring";
+	else if(!stricmp(tone, "ringtone"))
+		tone = "ring";
+	else if(!stricmp(tone, "busytone"))
+		tone = "busy";
+	else if(!stricmp(tone, "beep"))
+		tone = "record";
+	else if(!stricmp(tone, "callwait"))
+		tone = "waiting";
+	else if(!stricmp(tone, "callback"))
+		tone = "recall";
+	
+	key = TelTone::find(tone, loc);
+	enter();
+	if(isLibexec(tsid))
+	{
+		if(audio.tone)
+		{
+			delete audio.tone;
+			audio.tone = NULL;
+		}
+		if(!key)
+		{
+			state.result = RESULT_INVALID;
+			event.id = RESTART_LIBEXEC;
+			goto post;
+		}
+		audio.tone = new TelTone(key, level, getToneFraming());
+		state.timeout = timeout;
+		state.tone.exiting = false;
+		
+post:
+		postEvent(&event);
+	}
+	leave();
+}	
+
+void BayonneTSession::sysSTone(const char *tsid, char *tok)
+{
+	Event event;
+	unsigned f1 = 0;
+	const char *cp;
+	timeout_t timeout = TIMEOUT_INF;
+	Audio::Level level = 26000;
+	TelTone::tonekey_t *key;
+
+	memset(&event, 0, sizeof(event));
+	event.id = TONE_LIBEXEC;
+	event.libexec.tid = tsid;
+
+	cp = strtok_r(NULL, " \t\r\n", &tok);
+	if(cp)
+		f1 = atoi(cp);
+	cp = strtok_r(NULL, " \t\r\n", &tok);
+	if(cp)
+		timeout = atol(cp);
+	cp = strtok_r(NULL, " \t\r\n", &tok);
+	if(cp && atoi(cp) > 0)
+		level = atoi(cp);
+	if(!timeout)
+		timeout = TIMEOUT_INF;
+	else if(timeout < 10)
+		timeout *= 1000;
+	
+	enter();
+	if(isLibexec(tsid))
+	{
+		if(audio.tone)
+		{
+			delete audio.tone;
+			audio.tone = NULL;
+		}
+		audio.tone = new AudioTone(f1, level, getToneFraming());
+		state.timeout = timeout;
+		state.tone.exiting = false;
+		
+post:
+		postEvent(&event);
+	}
+	leave();
+}	
+
+void BayonneTSession::sysDTone(const char *tsid, char *tok)
+{
+	Event event;
+	unsigned f1 = 0, f2 = 0;
+	const char *cp;
+	timeout_t timeout = TIMEOUT_INF;
+	Audio::Level level = 26000;
+	TelTone::tonekey_t *key;
+
+	memset(&event, 0, sizeof(event));
+	event.id = TONE_LIBEXEC;
+	event.libexec.tid = tsid;
+
+	cp = strtok_r(NULL, " \t\r\n", &tok);
+	if(cp)
+		f1 = atoi(cp);
+	cp = strtok_r(NULL, " \t\r\n", &tok);
+	if(cp)
+		f2 = atoi(cp);
+	cp = strtok_r(NULL, " \t\r\n", &tok);
+	if(cp)
+		timeout = atol(cp);
+	cp = strtok_r(NULL, " \t\r\n", &tok);
+	if(cp && atoi(cp) > 0)
+		level = atoi(cp);
+	if(!timeout)
+		timeout = TIMEOUT_INF;
+	else if(timeout < 10)
+		timeout *= 1000;
+	
+	enter();
+	if(isLibexec(tsid))
+	{
+		if(audio.tone)
+		{
+			delete audio.tone;
+			audio.tone = NULL;
+		}
+		audio.tone = new AudioTone(f1, f2, level, level, getToneFraming());
+		state.timeout = timeout;
+		state.tone.exiting = false;
+		
+post:
+		postEvent(&event);
+	}
+	leave();
+}	
 
 void BayonneTSession::sysRecord(const char *tsid, char *tok)
 {
