@@ -175,8 +175,8 @@ const char *Checks::chkTransfer(Line *line, ScriptImage *img)
 	if(getMember(line))
 		return "transfer has no members";
 
-	if(hasKeywords(line))
-		return "transfer uses no keywords";
+	if(!useKeywords(line, "=prefix"))
+		return "invalid keyword used";
 
 	if(!getOption(line, &idx))
 		return "transfer destination required";
@@ -191,7 +191,7 @@ const char *Checks::chkDialer(Line *line, ScriptImage *img)
 	if(getMember(line))
 		return "dialers have no members";
 
-	if(!useKeywords(line, "=interdigit=level"))
+	if(!useKeywords(line, "=interdigit=level=prefix"))
 		return "unknown keyword for dialers";
 
 	if(!getOption(line, &idx))
