@@ -422,20 +422,27 @@ void loadConfig(void)
 		home = Process::getEnv("HOME");
 
 	if(!isDir(keypaths.getLast("config")))
-		keypaths.setValue("config", "/etc/bayonne");
+		keypaths.setValue("config", "/bayonne");
 
 	if(home)
 		snprintf(homepath, sizeof(homepath), "%s/.bayonne", home);
 	else
 		strcpy(homepath, "tempfiles");
 
-	if(getuid() && home)
+	if(Bayonne::provision_user)
 	{
 		keypaths.load("~bayonne/paths");
 		keyserver.load("~bayonne/server");
 		keyengine.load("~bayonne/engine");
 	}
 
+	if(Bayonne::provision_system)
+	{
+		keypaths.load("/bayonne/provision/paths");
+		keyserver.load("/bayonne/provision/server");
+		keyengine.load("/bayonne/provision/engine");
+	}
+
 	umask(007);
 	Process::setGroup(keyserver.getLast("group"));
 	Dir::create(keypaths.getLast("datafiles"));
