@@ -125,6 +125,7 @@ bool Methods::scrTransfer(void)
 	char nbuf[MAX_PATHNAME];
 	unsigned len = 0;
 	const char *cp;
+	const char *pre = getKeyword("prefix");
 
 	while(NULL != (cp = getValue(NULL)))
 	{
@@ -134,12 +135,22 @@ bool Methods::scrTransfer(void)
 
 	switch(iface)
 	{
+	case IF_INET:
+		if(pre)
+			snprintf(state.url.buf, sizeof(state.url.buf), "%s@%s", pre, nbuf);
+		else
+			snprintf(state.url.buf, sizeof(state.url.buf), "%s", nbuf);
+		state.url.ref = state.url.buf;
+		setState(STATE_XFER);
+		return false;
 	case IF_PSTN:	
+		if(!pre)
+			pre = "!";
 		state.tone.exiting = true;
 		if(audio.tone)
 			delete audio.tone;
-		state.tone.digits[0] = '!';
-		setString(state.tone.digits + 1, sizeof(state.tone.digits) - 1, nbuf);
+
+		snprintf(state.tone.digits, sizeof(state.tone.digits), "%s%s", pre, nbuf);
 		audio.tone = new DTMFTones(state.tone.digits, 20000, getToneFraming(), driver->getInterdigit());
 		setState(STATE_TONE);
 		return false;
