@@ -410,6 +410,12 @@ int main(int argc, char **argv)
         Process::setPosixSignal(SIGHUP, &stop);
         Process::setPosixSignal(SIGTERM, &stop);
         Process::setPosixSignal(SIGABRT, &stop);
+
+	if(!getuid())
+		Bayonne::provision_system = true;
+	else if(Process::getEnv("HOME"))
+		Bayonne::provision_user = true;
+
 #endif
 
 	if(!stricmp(cp, "-version"))
